@@ -1,5 +1,5 @@
- ;;;;;;;;LineBreak
- (let ((tag "LineBreak"))
+;;;;;;;;LineBreak
+(let ((tag "LineBreak"))
  (if (d-Directive-standalone?  tag)
     (d-InfoDialog "This sign denotes a Line Break. The music after this point will start on new line. This line break must be on a bar line. Use the Conditional Directives menu to make the line break applicable only to specific layouts. Delete using Del or Backspace key.")
     (begin
@@ -8,6 +8,8 @@
                 (d-WarningDialog "The cursor is on a voice. Put line breaks in the main staff that the voice belongs to."))
 
             (let ((choice #f))
+                (if (not (d-Directive-standalone?))
+                    (while (not (Appending?)) (d-MoveCursorRight)))
                 (d-DirectivePut-standalone tag)
                 (d-DirectivePut-standalone-postfix tag "\\break")
                 (d-DirectivePut-standalone-gy tag -25)
