@@ -6,10 +6,10 @@
     
     (if data
         (set! current data)
-        (set! current "-0.5"))
+        (set! current "-2"))
     (set! size (d-GetUserInput (_ "Notehead Font Magnification") (_  "Give size required: ") current))
     (if size
         (begin
             (d-DirectivePut-note-prefix tag (string-append " \\tweak  font-size #" size " "))
             (d-DirectivePut-note-data tag size)
-            (d-SetSaved #f))))
\ No newline at end of file
+            (d-SetSaved #f))))
