@@ -24,7 +24,7 @@
 #include "denemo_types.h"
 
 void dnm_insertchord (DenemoProject  *gui, gint duration, input_mode mode, 
-		      gboolean rest);
+              gboolean rest);
 void dnm_insertmeasures (DenemoMovement  *si, gint number);
 void dnm_deleteobject (DenemoMovement *si);
 void dnm_deletemeasure (DenemoMovement *si);
@@ -33,10 +33,10 @@ void dnm_deletemeasure (DenemoMovement *si);
 void dnm_addornament(DenemoObject *obj, Ornament orn);
 void 
 dnm_setinitialclef(DenemoMovement *si, DenemoStaff *curstaffstruct, 
-		   enum clefs clef);
+           enum clefs clef);
 void 
 dnm_setinitialtimesig (DenemoMovement *si, DenemoStaff * curstaffstruct, 
-		       gint time1,gint time2, gboolean all_staves);
+               gint time1,gint time2, gboolean all_staves);
 void
 dnm_insert_timesig (DenemoMovement * si, DenemoStaff * curstaffstruct, gint time1, gint time2);
 
@@ -46,7 +46,7 @@ void dnm_set_denemo_name (GString *lily_name, GString *denemo_name);
 
 
 
-void dnm_addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift, gint dclef);
+void dnm_addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift);
 DenemoObject * dnm_newchord (gint baseduration, gint numdots, int tied);
 measurenode * dnm_addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all);
 /* create one DenemoObject of type not known to denemo otherwise 
