@@ -44,16 +44,13 @@ static gpointer
 process_thread_func (gpointer data)
 {
   GMutex *mutex = g_mutex_new ();
+  gint64 end_time;
+  g_mutex_lock (mutex);
 
   for (;;)
     {
-      // FIXME: GTimeVals are not monotonic
-      GTimeVal timeval;
-      g_get_current_time (&timeval);
-      g_time_val_add (&timeval, PLAYBACK_INTERVAL);
-
-      g_cond_timed_wait (process_cond, mutex, &timeval);
-
+      end_time = g_get_monotonic_time () +  (PLAYBACK_INTERVAL * G_TIME_SPAN_SECOND)/1000000;
+      g_cond_wait_until (process_cond, mutex, end_time);
       if (g_atomic_int_get (&quit_thread))
         {
           break;
@@ -166,8 +163,7 @@ alsa_seq_initialize (DenemoPrefs * config)
 
   process_cond = g_cond_new ();
 
-  process_thread = g_thread_create_full (process_thread_func, NULL, 262144, TRUE, FALSE, G_THREAD_PRIORITY_NORMAL, NULL);
-
+  process_thread =  g_thread_try_new ("ALSA process", process_thread_func, NULL, NULL);
 
   return 0;
 }
