@@ -20,6 +20,7 @@
 #include "core/view.h"
 #include "audio/pitchentry.h"
 #include "audio/instrumentname.h"
+#include "printview/svgview.h"
 
 #include <glib.h>
 #include <math.h>
@@ -296,11 +297,11 @@ get_time ()
 
 
 void
-generate_midi ()
+generate_midi (void)
 {
   if ((Denemo.project->movement->smf == NULL) || (Denemo.project->movement->smfsync != Denemo.project->movement->changecount))
     {
-      exportmidi (NULL, Denemo.project->movement, 0, 0);
+      exportmidi (NULL, Denemo.project->movement);
     }
 
   if (Denemo.project->movement->smf == NULL)
@@ -348,9 +349,8 @@ get_obj_for_start_time (smf_t * smf, gdouble time)
       g_debug("smf_seek_to_event failed");  //if (event) g_debug("sought for endObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
-  return NULL;
+  return get_object_for_time (time, TRUE);
 }
-
 //finds the first note which comes OFF after the passed time
 DenemoObject *
 get_obj_for_end_time (smf_t * smf, gdouble time)
@@ -372,7 +372,8 @@ get_obj_for_end_time (smf_t * smf, gdouble time)
       g_debug("smf_seek_to_event failed");//if (event) g_debug("sought for startObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
-  return NULL;
+  //midi is generated by LilyPond, no user_pointer, get timings from events.txt
+  return get_object_for_time (time, FALSE);
 }
 
 
@@ -392,8 +393,9 @@ action_note_into_score (gint mid_c_offset, gint enshift, gint octave)
   gui->last_source = INPUTMIDI;
   gui->movement->cursor_y = gui->movement->staffletter_y = mid_c_offset;
   gui->movement->cursor_y += 7 * octave;
-  shiftcursor (gui, mid_c_offset);
-  setenshift (gui->movement, enshift);
+  //shiftcursor (gui, mid_c_offset);
+  //setenshift (gui->movement, enshift);
+  edit_pitch (mid_c_offset, enshift);
   displayhelper (gui);
 }
 
@@ -545,7 +547,8 @@ get_previous (enharmonic * enote)
         {
           if (Denemo.project->movement->currentmeasure->prev && Denemo.project->movement->currentmeasure->prev->data)
             {
-              curObj = g_list_last (Denemo.project->movement->currentmeasure->prev->data)->data;
+             DenemoMeasure *m = (DenemoMeasure*)Denemo.project->movement->currentmeasure->prev->data;
+             curObj = m->objects?g_list_last (m->objects)->data:NULL;
             }
         }
     }
@@ -635,6 +638,9 @@ midiaction (gint notenum)
                     }
                   if (Denemo.project->movement->cursor_appending)
                     break;
+                    curObj = Denemo.project->movement->currentobject->data;
+                    thechord = (chord *) curObj->object;
+                    is_tied = thechord->is_tied;
                 }
               while ((!(Denemo.keyboard_state & ADDING_MASK)) && next_editable_note () && is_tied);
             }
@@ -715,9 +721,15 @@ set_midi_capture (gboolean set)
 void
 adjust_midi_velocity (gchar * buf, gint percent)
 {
-  if (Denemo.prefs.dynamic_compression == 99)
+  if ((command == MIDI_NOTE_ON) && buf[2])
+    buf[2] = 127 - (gint) ((127 - buf[2]) * percent / 100.0);
+}
+
+void add_after_touch (gchar * buf)
+{
+   if (Denemo.prefs.damping)
     {
-      static gdouble times[0x7F];
+      static gdouble times[0x7F]; //takes no account of channel, really only good for one channel.
       if (command == MIDI_NOTE_ON)
         {
           times[notenumber] = get_time ();
@@ -730,13 +742,9 @@ adjust_midi_velocity (gchar * buf, gint percent)
           buf[2] = 60 / exp ((get_time () - times[notenumber]) * 1);    //scale according to the time
           return;
         }
-    }
-
-  if (command == MIDI_NOTE_ON)
-    buf[2] = 127 - (gint) ((127 - buf[2]) * percent / 100.0);
+    } 
 }
 
-
 void
 process_midi_event (gchar * buf)
 {
@@ -910,6 +918,7 @@ void
 play_adjusted_midi_event (gchar * buf)
 {
   adjust_midi_velocity (buf, 100 - Denemo.prefs.dynamic_compression);
+  add_after_touch (buf);
   adjust_midi_channel (buf);                                   
   //g_print ("play adj midibytes 0x%hhX 0x%hhX 0x%hhX\n", *(buf+0), *(buf+1), *(buf+2));
   play_midi_event (DEFAULT_BACKEND, 0, (guchar*) buf);
