@@ -799,6 +799,9 @@ remove_tone_key (GtkAction* action, DenemoScriptParam *param)
   return delete_chordnote (Denemo.project);
 }
 
+// Note this function is RECURSIVE.
+// deletes the object before the cursor. If the measure is empty it moves to the end of the previous measure and calls itself.
+// after deleting an object it backs-up on any rhythm pattern being followed.
 void
 deletepreviousobject (GtkAction* action, DenemoScriptParam *param)
 {
@@ -808,25 +811,25 @@ deletepreviousobject (GtkAction* action, DenemoScriptParam *param)
     {
       /* Then move the cursor back */
       movecursorleft (NULL, NULL);
+      DenemoObject *curObj = (DenemoObject*)Denemo.project->movement->currentobject->data;
+      gboolean anote = (curObj->type == CHORD) && ((chord*)curObj->object)->notes;
       /* And delete */
       deleteobject (NULL, NULL);
       /* if you are following a rhythmic pattern then backup the pattern */
-#define g  (Denemo.project->rstep)
-      if ((Denemo.project->mode & (INPUTEDIT) && g))
+      if ((Denemo.project->mode & (INPUTEDIT) && Denemo.project->rstep))
         {
-#define CURRP ((RhythmPattern *)Denemo.project->currhythm->data)
-          g = g->prev;          /* list is circular - should we stop at beginning? */
+          if (anote)
+            Denemo.project->rstep = Denemo.project->rstep->prev;          /* rstep list of elements is circular */
           if (Denemo.project->cstep)
             {
-              Denemo.project->cstep = Denemo.project->cstep->prev ? Denemo.project->cstep->prev : g_list_last (CURRP->clipboard)->data;
+              RhythmPattern *cursnip = (RhythmPattern *)Denemo.project->currhythm->data;
+              Denemo.project->cstep = Denemo.project->cstep->prev ? Denemo.project->cstep->prev : g_list_last (Denemo.project->cstep);// cstep list of DenemoObjects is not circular
             }
-          if (((RhythmElement *) g->data)->icon)
+          if (((RhythmElement *) Denemo.project->rstep->data)->highlightlabel)
             {
-              GtkWidget *label = LABEL (CURRP->button);
-              gtk_label_set_markup (GTK_LABEL (label), ((RhythmElement *) g->data)->icon);
+                RhythmPattern *cursnip = (RhythmPattern *)Denemo.project->currhythm->data;
+                set_rhythm_label (cursnip, ((RhythmElement *) Denemo.project->rstep->data)->highlightlabel);
             }
-#undef CURRP
-#undef g
         }
 
     }
@@ -852,7 +855,7 @@ deletepreviousobject (GtkAction* action, DenemoScriptParam *param)
           if (Denemo.project->movement->currentobject)
             {
               movecursorright (NULL, NULL);
-              deletepreviousobject (NULL, NULL);
+              deletepreviousobject (NULL, NULL);//RECURSIVE!!
             }
         }
     }
@@ -916,15 +919,18 @@ stem_down (GtkAction* action, DenemoScriptParam *param)
 void
 tie_notes_key (GtkAction* action, DenemoScriptParam *param)
 {
-  DenemoObject *curmudelaobj = (DenemoObject *) (Denemo.project->movement->currentobject ? Denemo.project->movement->currentobject->data : NULL);
+  DenemoObject *curObj = (DenemoObject *) (Denemo.project->movement->currentobject ? Denemo.project->movement->currentobject->data : NULL);
 
   /* Equals - toggle whether this note is tied */
-  if (curmudelaobj && curmudelaobj->type == CHORD && ((chord *) curmudelaobj->object)->notes)
+  if (curObj && curObj->type == CHORD && ((chord *) curObj->object)->notes)
     {
         if (Denemo.project->movement->cursor_appending)
             {
+              DenemoMovement *si = Denemo.project->movement;
+              gint tickspermeasure =  WHOLE_NUMTICKS * ((DenemoMeasure*)si->currentmeasure->data)->timesig->time1 / ((DenemoMeasure*)si->currentmeasure->data)->timesig->time2;
+              si->cursoroffend = (curObj->starttickofnextnote >= tickspermeasure);
               insertion_point (Denemo.project->movement);
-              object_insert (Denemo.project, dnm_clone_object (curmudelaobj));
+              object_insert (Denemo.project, dnm_clone_object (curObj));
               movecursorleft (NULL, NULL);
               movecursorleft (NULL, NULL);
               toggle_tie (NULL, NULL);
@@ -932,7 +938,7 @@ tie_notes_key (GtkAction* action, DenemoScriptParam *param)
               movecursorright (NULL, NULL);
           } else
           {
-              object_insert (Denemo.project, dnm_clone_object (curmudelaobj));
+              object_insert (Denemo.project, dnm_clone_object (curObj));
               movecursorleft (NULL, NULL);
               ((chord *) ((DenemoObject *)Denemo.project->movement->currentobject->data)->object)->is_tied = 1;
               movecursorright (NULL, NULL);
