@@ -15,8 +15,10 @@
 #include "command/staff.h"
 #include "string.h"
 #include "core/utils.h"
+#include "core/cache.h"
 #include "command/select.h"
 #include "display/displayanimation.h"
+#include "command/commandfuncs.h"
 
 #define STEMDIFFERENCE 6
 #define HALFSTEMDIFFERENCE 3
@@ -46,14 +48,17 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
           for (j = 1, curstaff = si->thescore; curstaff; j++, curstaff = curstaff->next)
             {
               store_for_undo_measure_insert (si, j, pos);
-              ((DenemoStaff *) curstaff->data)->measures = g_list_insert (staff_first_measure_node (curstaff), barlinenode, pos);
+              barlinenode = g_malloc0 (sizeof (DenemoMeasure)); //use NULL  originally
+              ((DenemoStaff *) curstaff->data)->themeasures = g_list_insert (staff_first_measure_node (curstaff), barlinenode, pos);
               ((DenemoStaff *) curstaff->data)->nummeasures++;
             }
+            
         }
       else
         {
           store_for_undo_measure_insert (si, si->currentstaffnum, pos);
-          ((DenemoStaff *) si->currentstaff->data)->measures = g_list_insert (staff_first_measure_node (si->currentstaff), barlinenode, pos);
+           barlinenode = g_malloc0 (sizeof (DenemoMeasure)); //use NULL  originally
+          ((DenemoStaff *) si->currentstaff->data)->themeasures = g_list_insert (staff_first_measure_node (si->currentstaff), barlinenode, pos);
           ((DenemoStaff *) si->currentstaff->data)->nummeasures++;
         }
 
@@ -70,6 +75,12 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
 
 
     }
+    
+    
+    if (all)
+        cache_all();
+    else
+        cache_staff (si->currentstaff);
   set_measure_transition (-20 * nummeasures, all);
   measurenode *ret = g_list_nth (staff_first_measure_node (si->currentstaff), pos);
 //  displayhelper (Denemo.project);
@@ -107,7 +118,7 @@ freeobjlist (gpointer data, gpointer user_data)
   objnode *delobjs = (objnode *) data;
   if (delobjs)
     {
-      /* Free all the mudela objects */
+      /* Free all the Denemo objects */
       g_list_foreach (delobjs, freeit_object, NULL);
       /* Free the object list itself */
       g_list_free (delobjs);
@@ -130,10 +141,7 @@ staffremovemeasures (staffnode * curstaff, guint pos)
   take_snapshot ();
   measurenode *firstmeasure;
   measurenode *delmeasure;
-  if (((DenemoStaff *) curstaff->data)->is_parasite)
-    {
-      ((DenemoStaff *) curstaff->data)->measures = *((DenemoStaff *) curstaff->data)->is_parasite;
-    }
+
   firstmeasure = staff_first_measure_node (curstaff);
   delmeasure = g_list_nth (firstmeasure, pos);
   if (delmeasure)
@@ -143,13 +151,17 @@ staffremovemeasures (staffnode * curstaff, guint pos)
       //       firstmeasure, delmeasure, pos);
 
 
-      freeobjlist (delmeasure->data, NULL);
-      ((DenemoStaff *) curstaff->data)->measures = g_list_remove_link (firstmeasure, delmeasure);
+      freeobjlist (((DenemoMeasure*)delmeasure->data)->objects, NULL);
+      ((DenemoStaff *) curstaff->data)->themeasures = g_list_remove_link (firstmeasure, delmeasure); //FIXME DANGER
+      g_free ((DenemoMeasure*)delmeasure->data);
       g_list_free_1 (delmeasure);
 
       ((DenemoStaff *) curstaff->data)->nummeasures--;
     }
+ if ( ((DenemoStaff *) curstaff->data)->themeasures == NULL)
+    return;
 //if the removed measures have a clef change in them the noteheights may need to change so...  
+  cache_staff (curstaff);
   staff_fix_note_heights (curstaff->data);
 }
 
@@ -183,7 +195,7 @@ removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
                   staffremovemeasures (curstaff, pos);
                   if (!staff_first_measure_node (curstaff))
                     {
-                      ((DenemoStaff *) curstaff->data)->measures = g_list_append (NULL, NULL);
+                      ((DenemoStaff *) curstaff->data)->themeasures = g_list_append (NULL, g_malloc0(sizeof (DenemoMeasure)));
                       ((DenemoStaff *) curstaff->data)->nummeasures = 1;
                     }
                 }
@@ -202,6 +214,7 @@ removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
             }
         }
       set_measure_transition (20, all);
+      all?  cache_all (): cache_staff (si->currentstaff);
     }
   else
     {
@@ -428,8 +441,11 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum, gint beamgroup_
  * next measure -- see staff_beams_and_stems_dirs for details
   */
 void
-calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint * time2, gint * stem_directive)
-{
+calculatebeamsandstemdirs (DenemoMeasure *measure)
+{ 
+  if (measure == NULL) 
+    return;
+  objnode * theobjs = measure->objects;
   DenemoObject *prevobj = NULL, *theobj;
   objnode *curobjnode, *starter = NULL;
   chord chordval;
@@ -438,11 +454,19 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint *
   gint beamgroup_number = 0;
   gint beamgroup_highest = 0;
   gint beamgroup_lowest = 0;
-  gint next_clef = *pclef;      /* Useful for when a clef intrudes
-                                   mid-beamgroup */
-  gint next_stem_directive = *stem_directive;
+  
+  
   gboolean isbeambreak;
-
+  gint  theclef = measure->clef->type;
+  gint  thetime1 = measure->timesig->time1;
+  gint  thetime2 = measure->timesig->time2;
+  gint  thestem_directive = measure->stemdir->type;
+  gint next_clef = theclef;      /* Useful for when a clef intrudes
+                                   mid-beamgroup */
+  gint next_stem_directive = thestem_directive;
+  
+  if (theobjs==NULL)
+    return;
 #if 0
   {
     static gint count = 0;
@@ -454,20 +478,8 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint *
           ------------------------------\n", count, stem == 2 ? "Neutral" : stem == 1 ? "Down" : "Up", next_clef);
   }
 #endif
-  /* Check to see there is a time signature change indicator, is so use for whole measure
-   */
-  for (curobjnode = theobjs; curobjnode; curobjnode = curobjnode->next)
-    {
-      theobj = (DenemoObject *) curobjnode->data;
 
-      if (theobj->type == TIMESIG)
-        {
-          *time1 = ((timesig *) theobj->object)->time1;
-          *time2 = ((timesig *) theobj->object)->time2;
-        }
-    }
-
-  ticksperbeat = calcticksperbeat (*time1, *time2);
+  ticksperbeat = calcticksperbeat (thetime1, thetime2);
   settickvalsinmeasure (theobjs);
   beatendsat = ticksperbeat;
 
@@ -541,14 +553,14 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint *
       if (prevobj && !prevobj->isend_beamgroup && theobj->isstart_beamgroup)
         {
           prevobj->isend_beamgroup = TRUE;
-          setsdir (starter, curobjnode->prev, beamgroup_sum, beamgroup_number, beamgroup_highest, beamgroup_lowest, *pclef, *stem_directive);
+          setsdir (starter, curobjnode->prev, beamgroup_sum, beamgroup_number, beamgroup_highest, beamgroup_lowest, theclef, thestem_directive);
         }
 
       /* Now that we've determined this note's status, what to actually
        * do about it: */
 
-      *pclef = next_clef;
-      *stem_directive = next_stem_directive;
+      theclef = theobj->clef->type;
+      thestem_directive = theobj->stemdir->type;
 
       if (theobj->isstart_beamgroup)
         {
@@ -567,11 +579,11 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint *
         }
       if (theobj->isend_beamgroup)
         {
-          setsdir (starter, curobjnode, beamgroup_sum, beamgroup_number, beamgroup_highest, beamgroup_lowest, *pclef, *stem_directive);
+          setsdir (starter, curobjnode, beamgroup_sum, beamgroup_number, beamgroup_highest, beamgroup_lowest, theclef, thestem_directive);
         }
     }                           /* End object loop */
 }                               /* End function */
-
+
 
 
 
@@ -643,11 +655,15 @@ set_accidental_positions (DenemoObject * the_chord)
 
 /**
  * Calculate which accidentials should be shown
- *
+ * for each note of each chord of the measure whose list of objects is passed in
+ * It also changes minpixelsalloted value of keysginatures to cope with the varying size (dependent on previous keysignature) by calling draw_key in dry-run mode.
  */
-gint
-showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
-{
+void
+showwhichaccidentals (objnode * theobjs)
+{ 
+  if(theobjs==NULL) return;
+  gint curkey;
+  gint * initialaccs;
   gint whatpersisted[7];
   static gint initialaccsthischord[7] = { UNSET, UNSET, UNSET, UNSET, UNSET, UNSET, UNSET };
   gint accsthischord[7];
@@ -655,18 +671,23 @@ showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
   gboolean contradicted[7];
   gint otn;                     /* offsettonumber */
   objnode *curobjnode;
-  DenemoObject *theobj;
+  DenemoObject *theobj = (DenemoObject *) theobjs->data;;
   GList *curtone;
   note *thetone;
   gint ret[7];
-  gint retnum = initialnum;
   gint i;
 
+  keysig *thekeysig = theobj->keysig;
+  curkey = thekeysig->number;
+  initialaccs = thekeysig->accs;
+
   memcpy (ret, initialaccs, SEVENGINTS);
   memcpy (whatpersisted, initialaccs, SEVENGINTS);
+  
   for (curobjnode = theobjs; curobjnode; curobjnode = curobjnode->next)
     {
       theobj = (DenemoObject *) curobjnode->data;
+      
       if (theobj->type == CHORD)
         {
           ((chord *) theobj->object)->hasanacc = FALSE;
@@ -706,6 +727,8 @@ showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
                 thetone->showaccidental = ((chord *) theobj->object)->hasanacc = TRUE;
               else
                 thetone->showaccidental = FALSE;
+                
+                
               // FIXME - you should use a script to apply these directives & set hasnacc with that.
               if (thetone->directives && ((DenemoDirective *) thetone->directives->data)->postfix && (*((DenemoDirective *) thetone->directives->data)->postfix->str == '!' || *((DenemoDirective *) thetone->directives->data)->postfix->str == '?'))
                 thetone->showaccidental = ((chord *) theobj->object)->hasanacc = (*((DenemoDirective *) thetone->directives->data)->postfix->str == '?') ? DENEMO_CAUTIONARY : DENEMO_REMINDER;
@@ -718,16 +741,15 @@ showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
         {
           for (i = 0; i < 7; i++)
             initialaccsthischord[i] = UNSET;
-          memcpy (ret, ((keysig *) theobj->object)->accs, SEVENGINTS);
-          memcpy (whatpersisted, ret, SEVENGINTS);
-          theobj->minpixelsalloted = draw_key (NULL, 0, 0, ((keysig *) theobj->object)->number, retnum, 0, FALSE, (keysig *) theobj->object);
-          retnum = ((keysig *) theobj->object)->number;
+            memcpy (ret, ((keysig *) theobj->object)->accs, SEVENGINTS);
+            memcpy (whatpersisted, ret, SEVENGINTS);
+            theobj->minpixelsalloted = draw_key (NULL, 0, 0, ((keysig *) theobj->object)->number, curkey, 0, FALSE, (keysig *) theobj->object);
+            curkey = ((keysig *) theobj->object)->number;
         }
-
-
+    
     }                           /* End object loop */
-  memcpy (initialaccs, ret, SEVENGINTS);
-  return retnum;
+  //memcpy (initialaccs, ret, SEVENGINTS);
+  
 }
 
 /**
@@ -761,7 +783,7 @@ forceaccidentals (DenemoObject * theobj)
 objnode *
 measure_first_obj_node (measurenode * mnode)
 {
-  return (objnode *) mnode->data;
+  return mnode?(objnode *) ((DenemoMeasure*)mnode->data)->objects:NULL; //FIXME DANGER was expecting a node with NULL data for the first object in the case of an empty measure.
 }
 
 /**
@@ -772,5 +794,5 @@ measure_first_obj_node (measurenode * mnode)
 objnode *
 measure_last_obj_node (measurenode * mnode)
 {
-  return g_list_last ((objnode *) mnode->data);
+  return g_list_last ((objnode *) ((DenemoMeasure*)mnode->data)->objects);
 }
