@@ -195,7 +195,6 @@ saveselection (DenemoMovement * si)
 {
   if (si->markstaffnum == 0)    /* Indicator that there's no selection.  */
     return;
-
   clearbuffer ();
 
   staffsinbuffer = si->selection.laststaffmarked - si->selection.firststaffmarked + 1;
@@ -231,10 +230,20 @@ copytobuffer (DenemoMovement * si)
   gint i = 0, j = 0, k = 0;
 
   if (si->markstaffnum == 0)    /* Indicator that there's no selection.  */
-    return;
-
+    {
+     clearbuffer ();
+     call_out_to_guile ("(CreateScriptForDirective)");   
+     
+    }
+  else
+    {
+        call_out_to_guile ("(set! CreateScriptForDirective::clipboard #f)");
+        Denemo.project->movement->directive_on_clipboard = NULL;
+    }
+  if  (si->markstaffnum == 0)
+        return;
   clearbuffer ();
-
+  si->selection_is_copied = TRUE;
   staffsinbuffer = si->selection.laststaffmarked - si->selection.firststaffmarked + 1;
   g_debug ("No staffs in copybuffer %d\n", staffsinbuffer);
   /* Staff loop.  */
@@ -623,6 +632,7 @@ get_point_object (void)
 static void
 mark_boundaries_helper (DenemoMovement * si, gint mark_staff, gint mark_measure, gint mark_object, gint point_staff, gint point_measure, gint point_object, enum drag_selection_type type)
 {
+  si->selection_is_copied = FALSE;
   if (mark_staff)
     {
       si->selection.firststaffmarked = MIN (mark_staff, point_staff);
@@ -683,6 +693,7 @@ void
 set_mark (GtkAction* action, DenemoScriptParam * param)
 {
   DenemoMovement *si = Denemo.project->movement;
+  si->selection_is_copied = FALSE;
   si->markstaffnum = si->currentstaffnum;
   si->markmeasurenum = si->currentmeasurenum;
   si->markcursor_x = si->cursor_x;
@@ -957,7 +968,11 @@ void
 pastewrapper (GtkAction * action, DenemoScriptParam * param)
 {
   stage_undo (Denemo.project->movement, ACTION_STAGE_END);        //undo is a queue (ie stack) so we push the end first
-  call_out_to_guile ("(DenemoPaste)");
+  
+  if (copybuffer == NULL)
+    call_out_to_guile ("(eval-string CreateScriptForDirective::clipboard)");
+  else
+    call_out_to_guile ("(DenemoPaste)");
   //FIXME if not success a ACTION_SCRIPT_ERROR will have been put in the undo queue...
   stage_undo (Denemo.project->movement, ACTION_STAGE_START);
 
