@@ -259,7 +259,10 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
     if (itp->mark)
       {
         cairo_save (cr);
-        cairo_set_source_rgba (cr, 0.8, 0.8, 0.4, 0.7);
+        if (si->selection_is_copied)
+            cairo_set_source_rgba (cr, 0.4, 0.8, 0.5, 0.7);
+        else
+            cairo_set_source_rgba (cr, 0.8, 0.8, 0.4, 0.7);
         cairo_rectangle (cr, x + mudelaitem->x, y, mudelaitem->minpixelsalloted, 80);
         cairo_fill (cr);
         cairo_restore (cr);
@@ -727,9 +730,9 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
  * @param y
  * @param gui
  * @param itp
- * return TRUE if measure has correct number of beats
+ * return nothing
  */
-static gboolean
+static void
 draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProject * gui, struct infotopass *itp)
 {
   static GString *mstring;
@@ -851,10 +854,11 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
             } 
       if (curmeasure->data)
         {
-            
-            if (extra_ticks == -itp->tickspermeasure)
+            //overfull or underfull measure indicator 
+          if (extra_ticks == -itp->tickspermeasure)
                 extra_ticks = 0;//allow empty measures
-            
+          if(itp->time1 == 256) //Cadenza Time
+                extra_ticks = 0;
           if (extra_ticks > 0)
                 cairo_set_source_rgba (cr, 1.0, 0.6, 0.6, OPACITY);
           else if ((extra_ticks < 0)/* && curmeasure->next*/)
@@ -904,7 +908,6 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
       cairo_restore (cr);
     }                           //if cr
 
-  return extra_ticks != 0;
 }
 
 /**
