@@ -16,9 +16,12 @@
 #include "ui/moveviewport.h"
 #include "ui/mousing.h"
 #include "audio/fluid.h"
+#include "audio/playback.h"
 #include "display/draw.h"
 #include "core/view.h"
 #include "audio/audiointerface.h"
+#include "export/exportmidi.h"
+
 
 static gboolean lh_down;
 static gdouble last_event_x;
@@ -85,21 +88,23 @@ get_click_height (DenemoProject * gui, gdouble y)
   DenemoStaff *staff;
   gint extra_space = 0;
   gint space_below = 0;
+  gint i;
   curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1);
 
   if (!(((DenemoStaff *) (gui->movement->currentstaff->data))->voicecontrol & DENEMO_PRIMARY))
     staffs_from_top--;
 
-  for (curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1); curstaff; curstaff = curstaff->next)
+  for (i=0, curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1); curstaff; i++, curstaff = curstaff->next)
     {
-      //g_debug("before extra space %d\n", extra_space);
       staff = (DenemoStaff *) curstaff->data;
+     // g_print("%d from top, staff %d extra space %d (next is %d %d  %d) previous space_below = %d)\n", i, gui->movement->currentstaffnum, extra_space, staff->space_above, staff->space_shorten, staff->space_below, space_below);
+
       if (staff->hidden) continue;
       if (staff->voicecontrol & DENEMO_PRIMARY)
-        extra_space += (staff->space_above) + space_below;
+        extra_space += (staff->space_above - (i?staff->space_shorten:0)
+          + space_below);
       if (curstaff == gui->movement->currentstaff)
         break;
-
       if (staff->voicecontrol & DENEMO_PRIMARY)
         {
 
@@ -107,11 +112,11 @@ get_click_height (DenemoProject * gui, gdouble y)
           staffs_from_top++;
         }
       space_below = MAX (space_below, ((staff->space_below) + (staff->verse_views ? LYRICS_HEIGHT : 0)));
-      //g_debug("after extra space %d space_below %d\n", extra_space, space_below);
+     // g_print("after extra space %d space_below %d\n", extra_space, space_below);
     }
 
   click_height = y - (gui->movement->staffspace * staffs_from_top + gui->movement->staffspace / 4 + extra_space);
-  //g_debug("top staff is %d total %d staffs from top is %d click %f\n", gui->movement->top_staff, extra_space, staffs_from_top, click_height);
+  //g_print("top staff is %d total %d staffs from top is %d click %f\n", gui->movement->top_staff, extra_space, staffs_from_top, click_height);
 
   return click_height;
 
@@ -126,9 +131,25 @@ get_click_height (DenemoProject * gui, gdouble y)
 void
 set_cursor_y_from_click (DenemoProject * gui, gdouble y)
 {
+  DenemoStaff *staff = (DenemoStaff*)gui->movement->currentstaff->data;
+  gint cursorclef;
+  if (gui->movement->currentobject)
+    cursorclef = ((DenemoObject *)gui->movement->currentobject->data)->clef->type;
+  else
+    cursorclef = ((DenemoMeasure *)gui->movement->currentmeasure->data)->clef->type;
   /* Click height relative to the top of the staff.  */
   gdouble click_height = get_click_height (gui, y);
-  gui->movement->cursor_y = offset_from_height (click_height, (enum clefs) gui->movement->cursorclef);
+  gint offset = offset_from_height (click_height, (enum clefs) cursorclef);
+  //g_print ("Does %d come within range %d %d?\n", offset, staff->range_hi, staff->range_lo);
+  if (staff->range)
+  {
+    if(offset < staff->range_lo)
+        offset = staff->range_lo;
+    else
+      if(offset > staff->range_hi)
+        offset = staff->range_hi;
+  }
+  gui->movement->cursor_y = offset;
   gui->movement->staffletter_y = offsettonumber (gui->movement->cursor_y);
 }
 
@@ -170,7 +191,7 @@ staff_at (gint y, DenemoMovement * si)
 
       count++;
       if ((!staff->hidden) && (staff->voicecontrol & DENEMO_PRIMARY))
-        space += staff->space_above + staff->space_below + si->staffspace + (staff->verse_views ? LYRICS_HEIGHT : 0);
+        space += staff->space_above + staff->space_below - staff->space_shorten + si->staffspace + (staff->verse_views ? LYRICS_HEIGHT : 0);
       //g_debug("y %d and space %d count = %d\n",y,space, count);
     }
 
@@ -224,7 +245,7 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
   pi->the_measure = staff_nth_measure_node (pi->the_staff, pi->measure_number - 1);
   if (pi->the_measure != NULL)
     {                           /*check to make sure user did not click on empty space */
-      obj_iterator = (objnode *) pi->the_measure->data;
+      obj_iterator = (objnode *) ((DenemoMeasure *)pi->the_measure->data)->objects;
       pi->cursor_x = 0;
       pi->the_obj = NULL;
       if (obj_iterator)
@@ -579,7 +600,9 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
         get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
         change /= pi.measure_number;
         update_tempo_widget ( change);
-        set_tempo (); exportmidi (NULL, gui->movement, 0, 0);  
+        set_tempo ();
+        score_status (Denemo.project, TRUE); 
+        exportmidi (NULL, gui->movement);  
         gtk_widget_queue_draw(Denemo.scorearea);
         return TRUE; 
     }
@@ -630,7 +653,7 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
           gui->movement->currentmeasure = pi.the_measure;
           gui->movement->currentobject = pi.the_obj;
           gui->movement->cursor_x = pi.cursor_x;
-          gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) gui->movement->currentmeasure->data)));
+          gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) ((DenemoMeasure*)gui->movement->currentmeasure->data)->objects)));
 
           set_cursor_y_from_click (gui, event->y);
           if (lh_down & !selecting)
@@ -752,7 +775,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       if (Denemo.prefs.learning)
         MouseGestureShow(_("Press Left."), _("This moved the cursor to the measure offscreen left. The display is shifted to place that measure on screen."),
           MouseGesture);
-      moveto_currentmeasurenum (gui, gui->movement->leftmeasurenum - 1);
+      set_currentmeasurenum (gui, gui->movement->leftmeasurenum - 1);
       write_status (gui);
       draw_score_area();
       return TRUE;
@@ -762,11 +785,11 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       if ((pi.at_edge) && ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend))))//crashed here with the_obj 0x131 !!!
         {
           if ((gui->movement->currentmeasurenum != gui->movement->rightmeasurenum) &&
-                (!moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
-              moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum);
+                (!set_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
+              set_currentmeasurenum (gui, gui->movement->rightmeasurenum);
           else if ((gui->movement->cursor_appending) &&
-                (!moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
-              moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum);
+                (!set_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
+              set_currentmeasurenum (gui, gui->movement->rightmeasurenum);
 
 
           
@@ -790,7 +813,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       gui->movement->currentmeasure = pi.the_measure;
       gui->movement->currentobject = pi.the_obj;
       gui->movement->cursor_x = pi.cursor_x;
-      gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) gui->movement->currentmeasure->data)));
+      gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) ((DenemoMeasure*)gui->movement->currentmeasure->data)->objects)));
       set_cursor_y_from_click (gui, event->y);
       if (event->type==GDK_2BUTTON_PRESS) 
                 {
@@ -822,6 +845,17 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
             }
 
   gint offset = (gint) get_click_height (gui, event->y);
+  
+   if ((((DenemoStaff *) gui->movement->currentstaff->data)->voicecontrol != DENEMO_PRIMARY) 
+        && (gui->movement->leftmeasurenum == 1) && (event->x > gui->leftmargin) 
+        && ((event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key)))
+    {
+          infodialog(_("The clef shown here affects the display only (as this voice is displayed on the staff above)."
+          " You can change the display clef using the clef menu."
+          "\nWarning! you will get confused if you set the key signature or time signature of a voice different "
+          "to the staff it is typeset on. Run the Staff/Voice property editor to adjust any inconsistencies."));
+  
+    }
   if ((((DenemoStaff *) gui->movement->currentstaff->data)->voicecontrol == DENEMO_PRIMARY) && (gui->movement->leftmeasurenum == 1) && (event->x > gui->leftmargin))
     {
       if (event->x < (gui->leftmargin+35) - cmajor)
@@ -900,7 +934,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                             gint staffnum = choice?brace->startstaff:brace->endstaff;
                             //g_print ("Count is %d for start at %d\n", count, staffnum);
                             GtkWidget *menuitem = gtk_ui_manager_get_widget (Denemo.ui_manager, "/ObjectMenu/StaffMenu/StaffGroupings");
-                            goto_movement_staff_obj (NULL, -1, staffnum, 1, 0);
+                            goto_movement_staff_obj (NULL, -1, staffnum, 1, 0, 0);
                             if (menuitem)
                                 if (choice)
                                     gtk_menu_popup (GTK_MENU (gtk_menu_item_get_submenu (GTK_MENU_ITEM (menuitem))), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
@@ -925,7 +959,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
           gint offset = (gint) get_click_height (gui, event->y);
           if (offset < STAFF_HEIGHT / 2)
             {
-              if (((DenemoStaff *) gui->movement->currentstaff->data)->staff_directives)
+              if (((DenemoStaff *) gui->movement->currentstaff->data)->staff_directives, 1)
                 {
                   if (Denemo.prefs.learning)
                     MouseGestureShow(_("Click on Staff Directives."), _("This pops up the staff directives menu for editing"),
@@ -934,7 +968,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                 }
               return TRUE;
             }
-          else if (((DenemoStaff *) gui->movement->currentstaff->data)->voice_directives)
+          else if (((DenemoStaff *) gui->movement->currentstaff->data)->voice_directives, 1)
             {
               if (Denemo.prefs.learning)
                 MouseGestureShow(_("Click on Voice Directives."), _("This pops up the voice directives menu for editing"),
