@@ -136,6 +136,8 @@ static void set_limit (DenemoPalette *pal) {
         repack_palette (pal);
     } else g_warning("Cancelled %s", response);
 }
+
+
 static GtkWidget *get_palette_menu(DenemoPalette *pal) {
   GtkWidget *menu = gtk_menu_new ();
   GtkWidget *item = gtk_menu_item_new_with_label (_("Hide"));
@@ -145,6 +147,11 @@ static GtkWidget *get_palette_menu(DenemoPalette *pal) {
   {
     item = gtk_menu_item_new_with_label (_("Make Horizontal"));
     gtk_widget_set_tooltip_text (item, _("Arrange the buttons extending horizontally"));
+    //gtk_widget_add_events (item, GDK_ENTER_NOTIFY_MASK);
+    //g_signal_connect (item, "enter-notify-event", show_tooltip, _("Arrange the buttons extending horizontally"));
+    
+    
+    
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
     g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (toggle_rows), (gpointer) pal);
   } else
@@ -268,6 +275,11 @@ static void edit_tooltip_for_button (GtkWidget *button) {
     }
     g_free(newtooltip);
 }
+static void help_for_button (GtkWidget *button) {
+    gchar *tooltip = gtk_widget_get_tooltip_text (button);
+    if (tooltip)
+        infodialog (tooltip);
+}
 static void remove_button (GtkWidget *button) {
     DenemoPalette *pal = g_object_get_data (G_OBJECT(button), "palette");
     palette_delete_button (pal, button);
@@ -310,7 +322,11 @@ static void popup_button_menu(DenemoPalette *pal, GtkWidget *button) {
   GtkWidget *menu = gtk_menu_new ();
   GtkWidget *item;
   gboolean sensitive = gtk_widget_get_visible (gtk_widget_get_toplevel (Denemo.script_view));//some menu items should be insensitive if the Scheme window is not visible
-
+  item = gtk_menu_item_new_with_label (_("Help"));
+  gtk_widget_set_tooltip_text (item, _("Show the help for this button"));
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+  g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (help_for_button), (gpointer) button);
+  
   item = gtk_menu_item_new_with_label (_("Edit Label"));
   gtk_widget_set_tooltip_text (item, _("Edit the label of this button"));
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -394,7 +410,7 @@ DenemoPalette *get_palette (gchar *name)
     return NULL;
 }
 
-static button_pressed (GtkWidget *button, GdkEventButton  *event, DenemoPalette *pal)
+static gboolean button_pressed (GtkWidget *button, GdkEventButton  *event, DenemoPalette *pal)
 { 
     Denemo.currentpalette = pal;
     if (event->button == 1)
@@ -491,7 +507,7 @@ DenemoPalette *create_palette (gchar *name, gboolean docked, gboolean rows) {
             {
              gtk_window_set_default_size (GTK_WINDOW (pal->window), 200, 100);//try and get folk to notice it!
              gtk_window_present (GTK_WINDOW (pal->window));
-	     gtk_window_set_transient_for (GTK_WINDOW(pal->window), GTK_WINDOW(Denemo.window));
+         gtk_window_set_transient_for (GTK_WINDOW(pal->window), GTK_WINDOW(Denemo.window));
              gtk_window_set_keep_above  (GTK_WINDOW (pal->window), TRUE);
          }
  
