@@ -23,7 +23,7 @@ tomeasurenum (GtkAction * action, gpointer param)
 
   DenemoProject *gui = Denemo.project;
   gint measnum;
-  gint max_mesure = g_list_length (((DenemoStaff *) (gui->movement->thescore->data))->measures);
+  gint max_mesure = g_list_length (((DenemoStaff *) (gui->movement->thescore->data))->themeasures);
 
   if (!action)
     {
@@ -31,11 +31,11 @@ tomeasurenum (GtkAction * action, gpointer param)
         {
           measnum = atoi (((DenemoScriptParam *) param)->string->str);
           if (measnum > max_mesure)
-            moveto_currentmeasurenum (gui, max_mesure);
+            set_currentmeasurenum (gui, max_mesure);
           if (measnum <= 0)
-            moveto_currentmeasurenum (gui, 1);
+            set_currentmeasurenum (gui, 1);
           else
-            moveto_currentmeasurenum (gui, measnum);
+            set_currentmeasurenum (gui, measnum);
         }
     }
   else
@@ -45,7 +45,7 @@ tomeasurenum (GtkAction * action, gpointer param)
       GtkWidget *measure;
       static gint last_measure = 1;
 
-      dialog = gtk_dialog_new_with_buttons (_("Go to measure"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+      dialog = gtk_dialog_new_with_buttons (_("Go to measure"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), _("_OK"), GTK_RESPONSE_ACCEPT, _("_Cancel"), GTK_RESPONSE_REJECT, NULL);
 
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
@@ -63,7 +63,7 @@ tomeasurenum (GtkAction * action, gpointer param)
       if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
         {
           last_measure = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (measure));
-          moveto_currentmeasurenum (gui, last_measure);
+          set_currentmeasurenum (gui, last_measure);
         }
       gtk_widget_destroy (dialog);
     }
