@@ -1,4 +1,5 @@
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <unistd.h>
 #include <config.h>
 #include "common.h"
@@ -40,12 +41,13 @@ compare_denemo_files(gchar* fileA, gchar* fileB){
   gboolean equals = (g_strcmp0(contentA, contentB) == 0);
 
   if(!equals){
-    if (g_test_trap_fork (0, 0))
+    if (g_test_subprocess ())
       {
         //TODO: Dynamically find diff path if possible
         execl("/usr/bin/diff", "/usr/bin/diff", fileA, fileB, NULL);
         g_warn_if_reached ();
       }
+    g_test_trap_subprocess (NULL, 0, 0);
     g_test_trap_assert_passed ();
   }
   
@@ -117,11 +119,12 @@ test_open_blank_file(gpointer fixture, gconstpointer data)
 {
   gchar* input = g_build_filename(fixtures_dir, "denemo", "blank.denemo", NULL);
   g_test_print("Opening %s\n", input);
-  if (g_test_trap_fork (0, 0))
+  if (g_test_subprocess ())
     {
       execl(DENEMO, DENEMO, "-n", "-e", input, NULL);
       g_warn_if_reached ();
     }
+  g_test_trap_subprocess (NULL, 0, 0);
   g_test_trap_assert_passed ();
 }
 
@@ -137,21 +140,23 @@ test_open_save_blank_file(gpointer fixture, gconstpointer data)
   gchar* input_contents = NULL;
   gchar* output_contents = NULL;
 
-  if (g_test_trap_fork (0, 0))
+  if (g_test_subprocess ())
     {
       gchar* scheme = g_strdup_printf("(d-SaveAs \"%s\")(d-Quit)", output);
       execl(DENEMO, DENEMO, "-n", "-e", "-a", scheme, input, NULL);
       g_warn_if_reached ();
     }
+  g_test_trap_subprocess (NULL, 0, 0);
   g_test_trap_assert_passed ();
 
   g_assert(g_file_test(output, G_FILE_TEST_EXISTS));
 
-  if (g_test_trap_fork (0, 0))
+  if (g_test_subprocess ())
     {
       execl(DENEMO, DENEMO, "-n", "-e", output, NULL);
       g_warn_if_reached ();
     }
+  g_test_trap_subprocess (NULL, 0, 0);
   g_test_trap_assert_passed ();
   
   g_assert(compare_denemo_files(input, output));
@@ -166,7 +171,7 @@ static void
 test_open_save_complex_file(gpointer fixture, gconstpointer data)
 {
   const gchar* input = (const gchar*) data;
-  gchar* filename = basename(input);
+  gchar* filename = g_path_get_basename(input);
   gchar* base_name = get_basename(filename);
   gchar* extension = g_strrstr (input, ".") + 1;
   
@@ -175,7 +180,7 @@ test_open_save_complex_file(gpointer fixture, gconstpointer data)
   const gchar* reference = g_build_filename(ref_dir, extension, output_filename, NULL);
  
   g_test_print("Opening %s\n", input);
-  if (g_test_trap_fork (0, 0))
+  if (g_test_subprocess ())
     {
       gchar* scheme = g_strdup_printf("(d-SaveAs \"%s\")(d-Quit)", output);
       if(g_strcmp0("scm", extension) == 0)
@@ -184,16 +189,18 @@ test_open_save_complex_file(gpointer fixture, gconstpointer data)
         execl(DENEMO, DENEMO, "-n", "-e", "-a", scheme, input, NULL);
       g_warn_if_reached ();
     }
+  g_test_trap_subprocess (NULL, 0, 0);
   g_test_trap_assert_passed ();
 
   
   g_test_print("Finding and reopening %s\n", output);
   g_assert(g_file_test(output, G_FILE_TEST_EXISTS));
-  if (g_test_trap_fork (0, 0))
+  if (g_test_subprocess ())
   {
     execl(DENEMO, DENEMO, "-n", "-e", output, NULL);
     g_warn_if_reached ();
   }
+  g_test_trap_subprocess (NULL, 0, 0);
   g_test_trap_assert_passed ();
 
   
@@ -214,6 +221,7 @@ test_open_save_complex_file(gpointer fixture, gconstpointer data)
     }
   }
   g_remove(output);
+  g_free(filename);
 }
 
 /*******************************************************************************
@@ -233,11 +241,19 @@ parse_dir_and_run_complex_test(gchar* path, const gchar* extension)
   }
 
   GList* files = find_files_with_ext(path, extension);
+  // Ensure a unique test case path if called multiple times.
+  // Use the given path and extension and append a counter to the end.
+  gchar* test_case_path_fragment = g_strconcat("/integration/open-and-save-complex-file-", path, "-", extension, NULL);
+  int test_case_path_counter = 1;
   while(files){
     filename = g_build_filename(path, files->data, NULL);
-    g_test_add ("/integration/open-and-save-complex-file", gchar*, filename, setup, test_open_save_complex_file, teardown);
+    gchar* test_case_path = g_strdup_printf("%s-%d", test_case_path_fragment, test_case_path_counter);
+    g_test_add (test_case_path, gchar*, filename, setup, test_open_save_complex_file, teardown);
+    g_free(test_case_path);
+    test_case_path_counter ++;
     files = g_list_next(files);
   }
+  g_free(test_case_path_fragment);
 }
 
 int
@@ -265,7 +281,7 @@ main (int argc, char *argv[])
 
   parse_dir_and_run_complex_test(example_dir, ".denemo");
   parse_dir_and_run_complex_test(fixtures_dir, ".denemo");
-  parse_dir_and_run_complex_test(fixtures_dir, ".mxml");
+  // parse_dir_and_run_complex_test(fixtures_dir, ".mxml");
   parse_dir_and_run_complex_test(fixtures_dir, ".scm");
 
   return g_test_run ();
