@@ -595,7 +595,7 @@ path_data_append_cheader_start (GString * string, gchar * name)
   g_free (NAME);
 }
 
-static gchar *
+static void
 path_data_append_cheader_end (GString * string, gchar * name)
 {
   gchar *NAME = g_utf8_strup (name, -1);
@@ -641,7 +641,7 @@ main (int argc, char **argv)
 
   if (!target || !filenames)
     {
-      g_print (g_option_context_get_help (context, TRUE, NULL));
+      g_print ("%s", g_option_context_get_help (context, TRUE, NULL));
       return 1;
     }
 
